@@ -1,12 +1,14 @@
 # A copy of the internal lavaan functions
 # it is copied here to help pass the automated CRAN checks
-# all code here is owned by the various authors of the lavaan package, with minor modifications 
+# all code here is owned by the various authors of the lavaan package, with minor modifications
 
-lav_partable_full <- function (partable = NULL, 
-                               strict.exo = FALSE, free = FALSE,
-                               start = FALSE) {
-  stopifnot(!is.null(partable$lhs), !is.null(partable$op), 
-            !is.null(partable$rhs))
+lav_partable_full <- function(partable = NULL,
+                              strict.exo = FALSE, free = FALSE,
+                              start = FALSE) {
+  stopifnot(
+    !is.null(partable$lhs), !is.null(partable$op),
+    !is.null(partable$rhs)
+  )
   meanstructure <- any(partable$op == "~1")
   nblocks <- lav_partable_nblocks(partable)
   lv.names <- vnames(partable, type = "lv")
@@ -48,8 +50,10 @@ lav_partable_full <- function (partable = NULL,
   lv.op <- rep("~~", length(lv.lhs))
   r.lhs <- r.rhs <- r.op <- character(0)
   if (any(partable$op == "~")) {
-    eqs.names <- unique(c(partable$lhs[partable$op == "~"], 
-                          partable$rhs[partable$op == "~"]))
+    eqs.names <- unique(c(
+      partable$lhs[partable$op == "~"],
+      partable$rhs[partable$op == "~"]
+    ))
     eqs.y <- eqs.names
     if (strict.exo) {
       x.idx <- which(eqs.names %in% ov.names.x)
@@ -63,8 +67,8 @@ lav_partable_full <- function (partable = NULL,
     idx <- which(r.lhs == r.rhs)
     r.lhs <- r.lhs[-idx]
     r.rhs <- r.rhs[-idx]
-    bad.idx <- which(r.lhs %in% ov.names.ind & r.rhs %in% 
-                       lv.names)
+    bad.idx <- which(r.lhs %in% ov.names.ind & r.rhs %in%
+      lv.names)
     if (length(bad.idx) > 0L) {
       r.lhs <- r.lhs[-bad.idx]
       r.rhs <- r.rhs[-bad.idx]
@@ -84,8 +88,10 @@ lav_partable_full <- function (partable = NULL,
   }
   th.lhs <- th.rhs <- th.op <- character(0)
   if (length(ov.names.ord) > 0L) {
-    tmp <- strsplit(vnames(partable, "th"), 
-                    "\\|")
+    tmp <- strsplit(
+      vnames(partable, "th"),
+      "\\|"
+    )
     th.lhs <- sapply(tmp, function(x) x[1])
     th.rhs <- sapply(tmp, function(x) x[2])
     th.op <- rep("|", length(th.lhs))
@@ -106,8 +112,10 @@ lav_partable_full <- function (partable = NULL,
     op <- rep(op, times = nblocks)
     rhs <- rep(rhs, times = nblocks)
   }
-  LIST <- data.frame(lhs = lhs, op = op, rhs = rhs, block = block, 
-                     stringsAsFactors = FALSE)
+  LIST <- data.frame(
+    lhs = lhs, op = op, rhs = rhs, block = block,
+    stringsAsFactors = FALSE
+  )
   if (free) {
     LIST$free <- rep(0L, nrow(LIST))
   }
@@ -117,18 +125,22 @@ lav_partable_full <- function (partable = NULL,
   LIST
 }
 
-vnames <- function (partable, type = NULL, ..., warn = FALSE, ov.x.fatal = FALSE) 
-{
-  if (length(partable$lhs) == 0) 
+vnames <- function(partable, type = NULL, ..., warn = FALSE, ov.x.fatal = FALSE) {
+  if (length(partable$lhs) == 0) {
     return(character(0L))
+  }
   dotdotdot <- list(...)
-  type.list <- c("ov", "ov.x", "ov.nox", "ov.model", "ov.y", 
-                 "ov.num", "ov.ord", "ov.ind", "ov.orphan", "ov.interaction", 
-                 "th", "th.mean", "lv", "lv.regular", "lv.formative", 
-                 "lv.x", "lv.y", "lv.nox", "lv.nonnormal", "lv.interaction", 
-                 "eqs.y", "eqs.x")
-  stopifnot(is.list(partable), !missing(type), type %in% c(type.list, 
-                                                           "all"))
+  type.list <- c(
+    "ov", "ov.x", "ov.nox", "ov.model", "ov.y",
+    "ov.num", "ov.ord", "ov.ind", "ov.orphan", "ov.interaction",
+    "th", "th.mean", "lv", "lv.regular", "lv.formative",
+    "lv.x", "lv.y", "lv.nox", "lv.nonnormal", "lv.interaction",
+    "eqs.y", "eqs.x"
+  )
+  stopifnot(is.list(partable), !missing(type), type %in% c(
+    type.list,
+    "all"
+  ))
   if (length(type) == 1L && type == "all") {
     type <- type.list
   }
@@ -145,16 +157,20 @@ vnames <- function (partable, type = NULL, ..., warn = FALSE, ov.x.fatal = FALSE
       block.var <- dot.names[dot]
       block.val <- dotdotdot[[block.var]]
       if (is.null(partable[[block.var]])) {
-        stop("lavaan ERROR: selection variable `", block.var, 
-             " not found in the parameter table.")
+        stop(
+          "lavaan ERROR: selection variable `", block.var,
+          " not found in the parameter table."
+        )
       }
       else {
         if (!all(block.val %in% partable[[block.var]])) {
-          stop("lavaan ERROR: ", block.var, " column does not contain value `", 
-               block.val, "'")
+          stop(
+            "lavaan ERROR: ", block.var, " column does not contain value `",
+            block.val, "'"
+          )
         }
-        block.select <- (block.select & partable[[block.var]] %in% 
-                           block.val)
+        block.select <- (block.select & partable[[block.var]] %in%
+          block.val)
       }
     }
     block.select <- unique(partable$block[block.select])
@@ -186,10 +202,10 @@ vnames <- function (partable, type = NULL, ..., warn = FALSE, ov.x.fatal = FALSE
   OUT$eqs.y <- vector("list", length = nblocks)
   OUT$eqs.x <- vector("list", length = nblocks)
   for (b in block.select) {
-    lv.names <- unique(partable$lhs[partable$block == b & 
-                                      (partable$op == "=~" | partable$op == "<~")])
-    int.names <- unique(partable$rhs[partable$block == b & 
-                                       grepl(":", partable$rhs)])
+    lv.names <- unique(partable$lhs[partable$block == b &
+      (partable$op == "=~" | partable$op == "<~")])
+    int.names <- unique(partable$rhs[partable$block == b &
+      grepl(":", partable$rhs)])
     n.int <- length(int.names)
     if (n.int > 0L) {
       ok.idx <- logical(n.int)
@@ -209,54 +225,64 @@ vnames <- function (partable, type = NULL, ..., warn = FALSE, ov.x.fatal = FALSE
       OUT$lv[[b]] <- lv.names
     }
     if ("lv.regular" %in% type) {
-      out <- unique(partable$lhs[partable$block == b & 
-                                   partable$op == "=~"])
+      out <- unique(partable$lhs[partable$block == b &
+        partable$op == "=~"])
       OUT$lv.regular[[b]] <- out
     }
     if ("lv.interaction" %in% type) {
       OUT$lv.interaction[[b]] <- lv.interaction
     }
     if ("lv.formative" %in% type) {
-      out <- unique(partable$lhs[partable$block == b & 
-                                   partable$op == "<~"])
+      out <- unique(partable$lhs[partable$block == b &
+        partable$op == "<~"])
       OUT$lv.formative[[b]] <- out
     }
-    if (!(length(type) == 1L && type %in% c("lv", "lv.regular", 
-                                            "lv.nonnormal"))) {
-      eqs.y <- unique(partable$lhs[partable$block == b & 
-                                     partable$op == "~"])
+    if (!(length(type) == 1L && type %in% c(
+      "lv", "lv.regular",
+      "lv.nonnormal"
+    ))) {
+      eqs.y <- unique(partable$lhs[partable$block == b &
+        partable$op == "~"])
     }
     if ("eqs.y" %in% type) {
       OUT$eqs.y[[b]] <- eqs.y
     }
-    if (!(length(type) == 1L && type %in% c("lv", "lv.regular", 
-                                            "lv.nonnormal", "lv.x"))) {
-      eqs.x <- unique(partable$rhs[partable$block == b & 
-                                     (partable$op == "~" | partable$op == "<~")])
+    if (!(length(type) == 1L && type %in% c(
+      "lv", "lv.regular",
+      "lv.nonnormal", "lv.x"
+    ))) {
+      eqs.x <- unique(partable$rhs[partable$block == b &
+        (partable$op == "~" | partable$op == "<~")])
     }
     if ("eqs.x" %in% type) {
       OUT$eqs.x[[b]] <- eqs.x
     }
-    if (!(length(type) == 1L && type %in% c("lv", "lv.regular", 
-                                            "lv.nonnormal"))) {
-      v.ind <- unique(partable$rhs[partable$block == b & 
-                                     partable$op == "=~"])
+    if (!(length(type) == 1L && type %in% c(
+      "lv", "lv.regular",
+      "lv.nonnormal"
+    ))) {
+      v.ind <- unique(partable$rhs[partable$block == b &
+        partable$op == "=~"])
     }
-    if (!(length(type) == 1L && type %in% c("lv", "lv.regular", 
-                                            "lv.nonnormal", "lv.x", "lv.y"))) {
+    if (!(length(type) == 1L && type %in% c(
+      "lv", "lv.regular",
+      "lv.nonnormal", "lv.x", "lv.y"
+    ))) {
       ov.ind <- v.ind[!v.ind %in% lv.names]
       ov.y <- eqs.y[!eqs.y %in% c(lv.names, ov.ind)]
       ov.x <- eqs.x[!eqs.x %in% c(lv.names, ov.ind, ov.y)]
     }
-    if (!(length(type) == 1L && type %in% c("lv", "lv.regular", 
-                                            "lv.nonnormal", "lv.x", "lv.y"))) {
-      ov.cov <- c(partable$lhs[partable$block == b & partable$op == 
-                                 "~~" & !partable$lhs %in% lv.names], partable$rhs[partable$block == 
-                                                                                     b & partable$op == "~~" & !partable$rhs %in% 
-                                                                                     lv.names])
-      ov.int <- partable$lhs[partable$block == b & (partable$op == 
-                                                      "~1" | partable$op == "|") & !partable$lhs %in% 
-                               lv.names]
+    if (!(length(type) == 1L && type %in% c(
+      "lv", "lv.regular",
+      "lv.nonnormal", "lv.x", "lv.y"
+    ))) {
+      ov.cov <- c(partable$lhs[partable$block == b & partable$op ==
+        "~~" & !partable$lhs %in% lv.names], partable$rhs[partable$block ==
+        b & partable$op == "~~" & !partable$rhs %in%
+        lv.names])
+      ov.int <- partable$lhs[partable$block == b & (partable$op ==
+        "~1" | partable$op == "|") & !partable$lhs %in%
+        lv.names]
       ov.tmp <- c(ov.ind, ov.y, ov.x)
       ov.extra <- unique(c(ov.cov, ov.int))
       ov.names <- c(ov.tmp, ov.extra[!ov.extra %in% ov.tmp])
@@ -286,39 +312,49 @@ vnames <- function (partable, type = NULL, ..., warn = FALSE, ov.x.fatal = FALSE
       }
       OUT$ov.interaction[[b]] <- ov.interaction
     }
-    if (any(type %in% c("ov.x", "ov.nox", "ov.num", "ov.model", 
-                        "th.mean", "lv.nonnormal"))) {
+    if (any(type %in% c(
+      "ov.x", "ov.nox", "ov.num", "ov.model",
+      "th.mean", "lv.nonnormal"
+    ))) {
       if (is.null(partable$user)) {
         partable$user <- rep(1L, length(partable$lhs))
       }
-      vars <- c(partable$lhs[partable$block == b & partable$op == 
-                               "~1" & partable$user == 1], partable$lhs[partable$block == 
-                                                                          b & partable$op == "~~" & partable$user == 1], 
-                partable$rhs[partable$block == b & partable$op == 
-                               "~~" & partable$user == 1])
+      vars <- c(
+        partable$lhs[partable$block == b & partable$op ==
+          "~1" & partable$user == 1], partable$lhs[partable$block ==
+          b & partable$op == "~~" & partable$user == 1],
+        partable$rhs[partable$block == b & partable$op ==
+          "~~" & partable$user == 1]
+      )
       idx.no.x <- which(ov.x %in% vars)
       if (length(idx.no.x)) {
         if (ov.x.fatal) {
-          stop("lavaan ERROR: model syntax contains variance/covariance/intercept formulas\n  involving (an) exogenous variable(s): [", 
-               paste(ov.x[idx.no.x], collapse = " "), "];\n  Please remove them and try again.")
+          stop(
+            "lavaan ERROR: model syntax contains variance/covariance/intercept formulas\n  involving (an) exogenous variable(s): [",
+            paste(ov.x[idx.no.x], collapse = " "), "];\n  Please remove them and try again."
+          )
         }
         if (warn) {
-          warning("lavaan WARNING: model syntax contains variance/covariance/intercept formulas\n  involving (an) exogenous variable(s): [", 
-                  paste(ov.x[idx.no.x], collapse = " "), "];\n  Please use fixed.x=FALSE or leave them alone")
+          warning(
+            "lavaan WARNING: model syntax contains variance/covariance/intercept formulas\n  involving (an) exogenous variable(s): [",
+            paste(ov.x[idx.no.x], collapse = " "), "];\n  Please use fixed.x=FALSE or leave them alone"
+          )
         }
         ov.x <- ov.x[-idx.no.x]
       }
       ov.tmp.x <- ov.x
       if (!is.null(partable$exo)) {
-        ov.cov <- c(partable$lhs[partable$block == b & 
-                                   partable$op == "~~" & partable$exo == 1L], 
-                    partable$rhs[partable$block == b & partable$op == 
-                                   "~~" & partable$exo == 1L])
-        ov.int <- partable$lhs[partable$block == b & 
-                                 partable$op == "~1" & partable$exo == 1L]
+        ov.cov <- c(
+          partable$lhs[partable$block == b &
+            partable$op == "~~" & partable$exo == 1L],
+          partable$rhs[partable$block == b & partable$op ==
+            "~~" & partable$exo == 1L]
+        )
+        ov.int <- partable$lhs[partable$block == b &
+          partable$op == "~1" & partable$exo == 1L]
         ov.extra <- unique(c(ov.cov, ov.int))
-        ov.tmp.x <- c(ov.tmp.x, ov.extra[!ov.extra %in% 
-                                           ov.tmp.x])
+        ov.tmp.x <- c(ov.tmp.x, ov.extra[!ov.extra %in%
+          ov.tmp.x])
       }
       ov.names.x <- ov.tmp.x
     }
@@ -328,26 +364,30 @@ vnames <- function (partable, type = NULL, ..., warn = FALSE, ov.x.fatal = FALSE
     if ("ov.orphan" %in% type) {
       OUT$ov.orphan[[b]] <- ov.extra
     }
-    if (any(type %in% c("ov.nox", "ov.num", "ov.model", 
-                        "th.mean", "lv.nonnormal"))) {
+    if (any(type %in% c(
+      "ov.nox", "ov.num", "ov.model",
+      "th.mean", "lv.nonnormal"
+    ))) {
       ov.names.nox <- ov.names[!ov.names %in% ov.names.x]
     }
     if ("ov.nox" %in% type) {
       OUT$ov.nox[[b]] <- ov.names.nox
     }
     if ("ov.model" %in% type) {
-      if (any(partable$block == b & partable$op == "~" & 
-              partable$exo == 1L)) {
+      if (any(partable$block == b & partable$op == "~" &
+        partable$exo == 1L)) {
         OUT$ov.model[[b]] <- ov.names.nox
       }
       else {
         OUT$ov.model[[b]] <- ov.names
       }
     }
-    if (any(type %in% c("ov.ord", "th", "th.mean", "ov.num", 
-                        "lv.nonnormal"))) {
-      tmp <- unique(partable$lhs[partable$block == b & 
-                                   partable$op == "|"])
+    if (any(type %in% c(
+      "ov.ord", "th", "th.mean", "ov.num",
+      "lv.nonnormal"
+    ))) {
+      tmp <- unique(partable$lhs[partable$block == b &
+        partable$op == "|"])
       ord.names <- ov.names[ov.names %in% tmp]
     }
     if ("ov.ord" %in% type) {
@@ -360,13 +400,13 @@ vnames <- function (partable, type = NULL, ..., warn = FALSE, ov.x.fatal = FALSE
       OUT$ov.num[[b]] <- ov.num
     }
     if ("lv.nonnormal" %in% type) {
-      lv.reg <- unique(partable$lhs[partable$block == 
-                                      b & partable$op == "=~"])
+      lv.reg <- unique(partable$lhs[partable$block ==
+        b & partable$op == "=~"])
       if (length(lv.reg) > 0L) {
         out <- unlist(lapply(lv.reg, function(x) {
-          tmp.ind <- unique(partable$rhs[partable$block == 
-                                           b & partable$op == "=~" & partable$lhs == 
-                                           x])
+          tmp.ind <- unique(partable$rhs[partable$block ==
+            b & partable$op == "=~" & partable$lhs ==
+            x])
           if (!all(tmp.ind %in% ov.num)) {
             return(x)
           }
@@ -381,17 +421,18 @@ vnames <- function (partable, type = NULL, ..., warn = FALSE, ov.x.fatal = FALSE
       }
     }
     if (any(c("th", "th.mean") %in% type)) {
-      TH.lhs <- partable$lhs[partable$block == b & partable$op == 
-                               "|"]
-      TH.rhs <- partable$rhs[partable$block == b & partable$op == 
-                               "|"]
+      TH.lhs <- partable$lhs[partable$block == b & partable$op ==
+        "|"]
+      TH.rhs <- partable$rhs[partable$block == b & partable$op ==
+        "|"]
     }
     if ("th" %in% type) {
       if (length(ord.names) > 0L) {
         out <- unlist(lapply(ord.names, function(x) {
           idx <- which(x == TH.lhs)
-          TH <- unique(paste(TH.lhs[idx], "|", TH.rhs[idx], 
-                             sep = ""))
+          TH <- unique(paste(TH.lhs[idx], "|", TH.rhs[idx],
+            sep = ""
+          ))
           sort(TH)
         }))
       }
@@ -405,8 +446,9 @@ vnames <- function (partable, type = NULL, ..., warn = FALSE, ov.x.fatal = FALSE
         out <- unlist(lapply(ov.names.nox, function(x) {
           if (x %in% ord.names) {
             idx <- which(x == TH.lhs)
-            TH <- unique(paste(TH.lhs[idx], "|", TH.rhs[idx], 
-                               sep = ""))
+            TH <- unique(paste(TH.lhs[idx], "|", TH.rhs[idx],
+              sep = ""
+            ))
             sort(TH)
           }
           else {
@@ -431,8 +473,8 @@ vnames <- function (partable, type = NULL, ..., warn = FALSE, ov.x.fatal = FALSE
       OUT$ov.y[[b]] <- ov.names[ov.names %in% tmp]
     }
     if ("lv.y" %in% type) {
-      tmp <- eqs.y[!eqs.y %in% c(v.ind, eqs.x) & eqs.y %in% 
-                     lv.names]
+      tmp <- eqs.y[!eqs.y %in% c(v.ind, eqs.x) & eqs.y %in%
+        lv.names]
       OUT$lv.y[[b]] <- lv.names[lv.names %in% tmp]
     }
     if ("lv.nox" %in% type) {
@@ -457,8 +499,7 @@ vnames <- function (partable, type = NULL, ..., warn = FALSE, ov.x.fatal = FALSE
   OUT
 }
 
-lav_partable_nblocks <- function (partable) 
-{
+lav_partable_nblocks <- function(partable) {
   if (is.null(partable$block)) {
     nblocks <- 1L
   }
@@ -469,8 +510,7 @@ lav_partable_nblocks <- function (partable)
   nblocks
 }
 
-lav_partable_block_values <- function (partable) 
-{
+lav_partable_block_values <- function(partable) {
   if (is.null(partable$block)) {
     block.values <- 1L
   }
@@ -479,4 +519,4 @@ lav_partable_block_values <- function (partable)
     block.values <- unique(stats::na.omit(tmp))
   }
   block.values
-}
\ No newline at end of file
+}
